@@ -16,25 +16,43 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
-from enum import Enum
 import hashlib
+import logging
 import os
+from dataclasses import dataclass
+from enum import Enum
 from pathlib import Path
 from typing import Callable, Dict, Optional
 
-from dataclasses import dataclass
 from gnupg import GPG
 
 OPENVAS_GPG_HOME = "/etc/openvas/gnupg"
 
 
+logger = logging.getLogger(__name__)
+
+
+def __determine_default_gpg_home() -> Path:
+    gos_default = Path(OPENVAS_GPG_HOME)
+    if gos_default.exists():
+        return gos_default
+    user_default = Path.home() / ".gnupg"
+    if not user_default.exists():
+        logger.warning(
+            "No GnuPG home found; "
+            "please verify setup and set the GNUPGHOME variable if necessary"
+        )
+    return user_default
+
+
 def __default_gpg_home() -> GPG:
     """
     __defaultGpgHome tries to load the variable 'GNUPGHOME' or to guess it
     """
     manual = os.getenv("GNUPGHOME")
 
-    home = Path(manual) if manual else Path(OPENVAS_GPG_HOME)
+    home = Path(manual) if manual else __determine_default_gpg_home()
+    logger.debug("Using %s as GnuPG home.", home)
     return GPG(gnupghome=f"{home.absolute()}")
 
 
