@@ -16,21 +16,15 @@
 # along with this program. If not, see <http://www.gnu.org/licenses/>.
 
 import json
-from json.decoder import JSONDecodeError
 import logging
+from json.decoder import JSONDecodeError
 from pathlib import Path
 from typing import Callable, Dict, Optional
 
-from notus.scanner.models.packages import package_class_by_type
-
-from .gpg_sha_verifier import VerificationResult
-
 from ..errors import AdvisoriesLoadingError
-from ..models.packages.package import (
-    AdvisoryReference,
-    PackageAdvisories,
-    PackageType,
-)
+from ..models.packages import package_class_by_type
+from ..models.packages.package import PackageAdvisories, PackageType
+from .gpg_sha_verifier import VerificationResult
 from .loader import AdvisoriesLoader
 
 logger = logging.getLogger(__name__)
@@ -54,7 +48,7 @@ class JSONAdvisoriesLoader(AdvisoriesLoader):
         json_file_path = (
             self._advisories_directory_path / f"{os_file_name}.notus"
         )
-        # since the data is comming from the outside it should not crash
+        # since the data is coming from the outside it should not crash
         # on wrongfully send data instead print a warning and return None
         if not json_file_path.exists():
             logger.log(
@@ -80,7 +74,7 @@ class JSONAdvisoriesLoader(AdvisoriesLoader):
             )
 
         if json_file_path.stat().st_size < 2:
-            # the minimim size of a json file is 2 bytes ({} or [])
+            # the minimum size of a json file is 2 bytes ({} or [])
             return None
 
         with json_file_path.open("r", encoding="utf-8") as f:
@@ -129,7 +123,7 @@ class JSONAdvisoriesLoader(AdvisoriesLoader):
                 )
                 continue
 
-            advisory = AdvisoryReference(oid)
+            advisory = oid
 
             for package_dict in fixed_packages:
                 full_name = package_dict.get("full_name")
