@@ -16,19 +16,23 @@
 # along with this program. If not, see <http://www.gnu.org/licenses/>.
 
 from typing import Optional
-from notus.scanner.models.packages.deb import DEBPackage
-from notus.scanner.models.packages.ebuild import EBuildPackage
-from notus.scanner.models.packages.package import Package, PackageType
-from notus.scanner.models.packages.rpm import RPMPackage
+
+from .deb import DEBPackage
+from .ebuild import EBuildPackage
+from .package import Package, PackageType
+from .rpm import RPMPackage
+from .slackware import SlackPackage
+
+__SWITCHER = {
+    PackageType.RPM: RPMPackage,
+    PackageType.DEB: DEBPackage,
+    PackageType.EBUILD: EBuildPackage,
+    PackageType.SLACK: SlackPackage,
+}
 
 
 def package_class_by_type(pt: PackageType) -> Optional[Package]:
     """
     package_class_by_type may returns Package if defined otherwise None
     """
-    switcher = {
-        PackageType.RPM: RPMPackage,
-        PackageType.DEB: DEBPackage,
-        PackageType.EBUILD: EBuildPackage,
-    }
-    return switcher.get(pt)
+    return __SWITCHER.get(pt)
